tlslite.constants.Fault

Package tlslite :: Module constants :: Class Fault |
[show private | hide private]
[frames | no frames]

## Class Fault

Class Variable Summary
`int` | `badA` = 103
`int` | `badB` = 201
`int` | `badFinished` = 300
`int` | `badIdentifier` = 401
`int` | `badMAC` = 301
`int` | `badPadding` = 302
`int` | `badPassword` = 102
`int` | `badPremasterPadding` = 501
`int` | `badSharedKey` = 402
`int` | `badUsername` = 101
`int` | `badVerifyMessage` = 601
`list` | `clientCertFaults` = `[601]`
`list` | `clientNoAuthFaults` = `[501, 502]`
`list` | `clientSharedKeyFaults` = `[401, 402]`
`list` | `clientSrpFaults` = `[101, 102, 103]`
`dict` | `faultAlerts` = `{101: (120, 20), 102: (20,), 103: (47,), 3...`
`dict` | `faultNames` = `{101: 'bad username', 102: 'bad password', ...`
`list` | `genericFaults` = `[300, 301, 302]`
`list` | `serverFaults` = `[201]`
`int` | `shortPremasterSecret` = 502

Class Variable Details

    ### badA Type: `int` Value:
        103

    ### badB Type: `int` Value:
        201

    ### badFinished Type: `int` Value:
        300

    ### badIdentifier Type: `int` Value:
        401

    ### badMAC Type: `int` Value:
        301

    ### badPadding Type: `int` Value:
        302

    ### badPassword Type: `int` Value:
        102

    ### badPremasterPadding Type: `int` Value:
        501

    ### badSharedKey Type: `int` Value:
        402

    ### badUsername Type: `int` Value:
        101

    ### badVerifyMessage Type: `int` Value:
        601

    ### clientCertFaults Type: `list` Value:
        [601]

    ### clientNoAuthFaults Type: `list` Value:
        [501, 502]

    ### clientSharedKeyFaults Type: `list` Value:
        [401, 402]

    ### clientSrpFaults Type: `list` Value:
        [101, 102, 103]

    ### faultAlerts Type: `dict` Value:
        {101: (120, 20),
         102: (20,),
         103: (47,),
         300: (51,),
         301: (20,),
         302: (20,),
         401: (40,),
         402: (20,),
        ...

    ### faultNames Type: `dict` Value:
        {101: 'bad username',
         102: 'bad password',
         103: 'bad A',
         300: 'bad finished message',
         301: 'bad MAC',
         302: 'bad padding',
         401: 'bad identifier',
         402: 'bad sharedkey',
        ...

    ### genericFaults Type: `list` Value:
        [300, 301, 302]

    ### serverFaults Type: `list` Value:
        [201]

    ### shortPremasterSecret Type: `int` Value:
        502

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net